
// Glenn's POV-Ray Animation File - Bobsled Shot 265
// created 29-Dec-02
// last update 29-Dec-02
// 2002 Glenn McCarter  ( glenn@mccarters.net )

#include "GIncludeRH.inc"

//#include "GRuler.inc"

#version 3.5;
global_settings {
  adc_bailout 0.003922
  ambient_light <1.0,1.0,1.0>
  assumed_gamma 1.0
  hf_gray_16 off
  irid_wavelength <0.25,0.18,0.14>
  max_intersections 64
  max_trace_level 10
  number_of_waves 10
}


//===============================================
//             Variables
//===============================================

#declare ThisIsMaster = 1; // declares this the Master File, leave at 1
#declare RenderMe = 0; // supresses self-rendering of the include files, leave at 0
#declare DoFog = 0; // 0=no fog, 1=fog
#declare LocalOrigin = <320*Feet,400*Feet,0>; // end of straight 9
#declare Seconds = Sclock*(Sframes/FPS); // goes from 0+ to #-of-seconds in this shot

#include "TrackMaker.inc"

// 95 ft/sec
#declare SledPos = <0,100*Feet,2*Feet>;
#declare SledPos = SledPos + <0,-95*Feet*Seconds,0>;
#declare CamLook = <0,20*Feet,6*Feet>;

#if ( Debug = 1) #debug concat("SledPos:","<",str(SledPos.x,5,0),",",str(SledPos.y,5,0),",",str(SledPos.z,5,0),">","\n") #end
#if ( Debug = 1) #debug concat("Seconds: ",str(Seconds,5,3),"\n") #end

//===============================================
//             Cameras
//===============================================

#declare Render_Cam =
	camera {
  perspective
  direction <0.0,     1.0,  0.0>
  sky       <0.0,     0.0,  1.0>  // Use right handed-system!
  up        <0.0,     0.0,  1.0>  // Where Z is up
  right     <1.33333, 0.0,  0.0>
	angle 35-1.2*Seconds-1.0*Seconds*Seconds
  location  <-30*Feet,80*Feet,30*Feet>
  look_at   CamLook
}

#declare Special_Cam =
  camera {
  direction <0.0,     1.0,  0.0>
  sky       <0.0,     0.0,  1.0>  // Use right handed-system!
  up        <0.0,     0.0,  1.0>  // Where Z is up
  right     <1.33333, 0.0,  0.0>
    angle 65
//    direction z*50
//  location  <2*Feet, 50*Feet, 140*Feet> // overhead
//  look_at   <3*Feet, -0*Feet, 0*Feet >
  location  SledPos + <-3*Feet,1.5*Feet, 120*Feet>
  look_at   SledPos +<3*Feet,1.5*Feet, 320> 
  }


camera {
//  Special_Cam
  Render_Cam
  }


//===============================================
//             Textures
//===============================================

#declare BluePaintTex =
	texture {
		pigment { color rgb<.36,.38,.89> }
	}


//===============================================
//             Lighting
//===============================================

#include "TrackLights.inc"
object { TrackLight translate <-14*Feet,20*Feet,2*Feet> }
object { TrackLight translate <-14*Feet,80*Feet,2*Feet> }
object { TrackLight rotate z*-45 translate <-40*Feet,-24*Feet,2*Feet> }
object { TrackLight rotate z*45 translate <-40*Feet,130*Feet,2*Feet> }

//===============================================
//             Environment
//===============================================

#include "BobEnviron.inc"
object { Plain rotate x*-17 translate -LocalOrigin }
object { TrackTerrain translate -LocalOrigin }
object { NearbyMountains scale 1 rotate x*-17 translate <-1500*Feet,-1000*Feet,220*Feet> translate -LocalOrigin }
object { NearbyMountains scale 2 rotate z*180 rotate x*-17 translate <5000*Feet,1200*Feet ,-500*Feet> translate -LocalOrigin }


object { TotalTrack translate -LocalOrigin+<0,0,2*Feet> }


//===============================================
//             Objects
//===============================================

#include "Bobsled.inc"

#declare RS = seed(33708);

#declare SixFootSnowball =
	union {
		sphere { // main
			<0,0,0>,36
		}
		#declare SS = 0;
		#while (SS<80)
			sphere {
				<0,0,0>,4.2+rand(RS)*7.0
				translate <0,0,-33>
				rotate y*(0+360*rand(RS))
				rotate z*(0+360*rand(RS))
			}
			#declare SS = SS + 1;
		#end
		texture { IcyTex scale 0.3 }
	} // end union

#macro Snowball(Diam)
	sphere {
		<0,0,0>,Diam
		texture { IcyTex scale 0.3 }
	}
#end

//===============================================
//             Object Placement
//===============================================

#switch ( Seconds)
#range (0,1.0)
object { SixFootSnowball
	rotate x*(-360+Seconds*360)
	translate <15*Feet,40*Feet,(2.5+10)*Feet> // initial position
		+ <-15*Feet*Seconds,-20*Feet*Seconds,-10*Feet*Seconds> // velocities
}
#break
#range (1.001,2.0)
object { SixFootSnowball
	rotate x*(-360+1*360) // initial rotation
		+ x*((Seconds-1)*90-(Seconds-1)*(Seconds-1)*(90/4))
	translate <15*Feet,40*Feet,(2.5+10)*Feet>
		+ <-15*Feet*1,-20*Feet*1,-10*Feet*1> // initial position
		+ <0,-4*Feet*(Seconds-1)+(4/4)*Feet*(Seconds-1)*(Seconds-1),0>
}
#else
//object { SixFootSnowball translate <0*Feet,20*Feet,2.5*Feet> }
object { SixFootSnowball
	rotate x*(-360+1*360) // initial rotation
		+ x*((2-1)*90-(2-1)*(2-1)*(90/4))
		+ x*((Seconds-2)*-10)
	translate <15*Feet,40*Feet,(2.5+10)*Feet>
		+ <-15*Feet*1,-20*Feet*1,-10*Feet*1> // initial position
		+ <0,-4*Feet*(2-1)+(4/4)*Feet*(2-1)*(2-1),0>
}
#end

#if ( Seconds > 1 )
object { Snowball(9) translate <1*Feet,21*Feet,4.5*Feet>+<-14*Feet*(Seconds-1),-20*Feet*(Seconds-1),0*Feet*(Seconds-1)-32*Feet*(Seconds-1)*(Seconds-1)> }
object { Snowball(6) translate <0*Feet,20*Feet,5.0*Feet>+<-15*Feet*(Seconds-1),-21*Feet*(Seconds-1),2*Feet*(Seconds-1)-32*Feet*(Seconds-1)*(Seconds-1)> }
object { Snowball(5) translate <-1*Feet,19*Feet,4.0*Feet>+<-18*Feet*(Seconds-1),-12*Feet*(Seconds-1),6*Feet*(Seconds-1)-32*Feet*(Seconds-1)*(Seconds-1)> }
object { Snowball(3) translate <-0.8*Feet,19.5*Feet,4.0*Feet>+<-9*Feet*(Seconds-1),-25*Feet*(Seconds-1),12*Feet*(Seconds-1)-32*Feet*(Seconds-1)*(Seconds-1)> }
#end

